Learn R Programming

repfun (version 0.1.2)

mtcars_w2lbls: This is the mtcars data frame with labels added for columns mpg and cyl.

Description

mtcars_w2lbls

Usage

mtcars_w2lbls

Arguments

Format

A data frame with 32 observations and 11 columns:

mpg

Miles/(US) gallon

cyl

Number of cylinders

disp

Displacement (cu.in.)

hp

Gross horsepower

drat

Rear axle ratio

wt

Weight (1000 lbs)

qsec

1/4 mile time

vs

Engine (0 = V-shaped, 1 = straight)

am

Transmission (0 = automatic, 1 = manual)

gear

Number of forward gears

carb

Number of carburetors

Details

Updated version of the mtcars data frame that includes labels for 2 variables.

References

None

Examples

Run this code
data("mtcars_w2lbls")

Run the code above in your browser using DataLab